'use strict';

var _extends = require('babel-runtime/helpers/extends')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _mixinsDocHelpers = require('../mixins/DocHelpers');

var _mixinsDocHelpers2 = _interopRequireDefault(_mixinsDocHelpers);

var _ReactPlayground = require('./ReactPlayground');

var _ReactPlayground2 = _interopRequireDefault(_ReactPlayground);

var PropTypes = _react2['default'].PropTypes;

var ReactDocSection = _react2['default'].createClass({
  displayName: 'ReactDocSection',

  propTypes: {
    componentItem: PropTypes.object.isRequired,
    previewConfig: PropTypes.object,
    grouper: PropTypes.func
  },

  mixins: [_mixinsDocHelpers2['default']],

  renderProps: function renderProps(componentProps) {
    var _this = this;

    return (0, _lodash2['default'])(componentProps).keys().map(function (propKey, idx) {
      var propItem = componentProps[propKey];
      return _react2['default'].createElement(
        'div',
        { className: 'react-doc-section__prop',
          key: idx },
        _react2['default'].createElement(
          'h3',
          { className: 'react-doc-section__prop-title' },
          ' Prop: ',
          propKey,
          propItem.required ? _react2['default'].createElement(
            'span',
            null,
            ' *'
          ) : null
        ),
        _react2['default'].createElement(
          'small',
          { className: 'react-doc-section__prop-sub-title' },
          _this.processType(propItem.type)
        ),
        _react2['default'].createElement('div', { className: 'react-doc-section__prop-desc',
          dangerouslySetInnerHTML: {
            __html: propItem.description ? propItem.description : ''
          } }),
        _this.renderExamples(propItem.examples)
      );
    }).value();
  },

  processType: function processType(typeObject) {
    var _this2 = this;

    if (_lodash2['default'].isObject(typeObject)) {
      switch (typeObject.name) {

        case 'shape':

          return _react2['default'].createElement(
            'div',
            null,
            _react2['default'].createElement(
              'div',
              null,
              'Type: ' + typeObject.name
            ),
            _react2['default'].createElement(
              'table',
              null,
              _react2['default'].createElement(
                'tbody',
                null,
                (0, _lodash2['default'])(typeObject.value).keys().map(function (key, idx) {
                  return _react2['default'].createElement(
                    'tr',
                    { key: idx },
                    _react2['default'].createElement(
                      'td',
                      null,
                      key
                    ),
                    _react2['default'].createElement(
                      'td',
                      null,
                      _this2.processType(typeObject.value[key])
                    )
                  );
                }).value()
              )
            )
          );

        case 'enum':
        case 'union':

          return (0, _lodash2['default'])(typeObject.value).map(function (obj) {
            return _this2.processType(obj);
          }).join(' | ');

        case 'instanceOf':

          return 'Type: ' + typeObject.name + ' ' + typeObject.value;

        default:
          return typeObject.name ? 'Type: ' + typeObject.name : 'Value: ' + typeObject.value;
      }
    }
  },

  renderExamples: function renderExamples() {
    var _this3 = this;

    var examples = arguments.length <= 0 || arguments[0] === undefined ? [] : arguments[0];

    return _lodash2['default'].map(examples, function (exampleItem, idx) {
      return _react2['default'].createElement(_ReactPlayground2['default'], {
        key: idx,
        previewConfig: _this3.props.previewConfig,
        codeText: exampleItem.contents
      });
    });
  },

  render: function render() {

    var props = this.props;

    return _react2['default'].createElement(
      'section',
      _extends({}, props, {
        className: 'react-doc-section' }),
      _react2['default'].createElement(
        'h2',
        { className: 'react-doc-section__title' },
        props.componentItem.name,
        _react2['default'].createElement(
          'small',
          { className: 'react-doc-section__sub-title' },
          props.grouper(props.componentItem.module)
        )
      ),
      _react2['default'].createElement('div', { className: 'react-doc-section__desc',
        dangerouslySetInnerHTML: {
          __html: props.componentItem.description
        } }),
      this.renderExamples(props.componentItem.examples),
      this.renderProps(props.componentItem.props)
    );
  }
});

exports['default'] = ReactDocSection;
module.exports = exports['default'];